@@ -156,10 +156,10 @@ sub get_sidechain_name
     my $chain;
     if( blessed $start && $start->isa( ChemOnomatopist::Chain:: ) ) {
         $chain = $start;
-        $chain->parent( $parent ) if $parent;
+        $chain->parent( $parent ) if $parent && !$chain->parent;
     } elsif( $graph->groups( $start ) ) {
         ( $chain ) = $graph->groups( $start );
-        $chain->parent( $parent ) if $parent;
+        $chain->parent( $parent ) if $parent && !$chain->parent;
     } else {
         $chain = select_sidechain( $graph, $parent, $start );
     }
@@ -296,9 +296,6 @@ sub get_sidechain_name
 
     $name .= $chain->isotope_part;
 
-    # Record the parent
-    $chain->parent( $parent ) if $chain->can( 'parent' );
-
     if(  $chain->isa( ChemOnomatopist::Chain::Circular:: ) ||
          $chain->isa( ChemOnomatopist::Group:: ) ||
         ($chain->isa( ChemOnomatopist::Chain::Amine:: ) && @chain == 1) ||
@@ -1697,8 +1694,8 @@ sub order_by_neighbours($$$$)
                            [ reverse sort map { exists $_->{isotope} ? $_->{isotope} : atomic_number( $_ ) } @frontA ] );
         return $cmp if $cmp;
 
-        @frontA = neighbours_at_distance( $graph, $A, $parent, $distance, set( $parent ) );
-        @frontB = neighbours_at_distance( $graph, $B, $parent, $distance, set( $parent ) );
+        @frontA = neighbours_at_distance( $graph, $A, $distance, set( $parent ) );
+        @frontB = neighbours_at_distance( $graph, $B, $distance, set( $parent ) );
         $distance++;
     }
 
